@@ -4,7 +4,7 @@
 
 ;; Author: Artur Malabarba <emacs@endlessparentheses.com>
 ;; URL: http://github.com/Malabarba/smart-mode-line
-;; Version: 2.13
+;; Version: 2.14
 ;; Package-Requires: ((emacs "24.3") (rich-minority "0.1.1"))
 ;; Keywords: mode-line faces themes
 ;; Prefix: sml
@@ -398,9 +398,9 @@ Set SYM to VAL."
   (if val (setq sml/shortener-func 'sml/do-shorten-directory)
     (setq sml/shortener-func 'sml/not-shorten-directory)))
 
-(define-obsolete-variable-alias 'sml/time-format 'display-time-format)
-(define-obsolete-variable-alias 'sml/show-time 'display-time-mode)
-(define-obsolete-variable-alias 'sml/override-theme 'sml/theme)
+(define-obsolete-variable-alias 'sml/time-format 'display-time-format "2.0.3")
+(define-obsolete-variable-alias 'sml/show-time 'display-time-mode "2.0.3")
+(define-obsolete-variable-alias 'sml/override-theme 'sml/theme "2.0.3")
 
 (defcustom sml/theme 'automatic
   "Defines which theme `smart-mode-line' should use.
@@ -1367,11 +1367,11 @@ doesn't want any buffer-id."
 Argument IGNORED is ignored."
   (setq sml/name-width-old sml/name-width)
   (setq sml/buffer-identification-filling nil)
-  (when (or ;; Only calculate all this if it will actually be used
-         (equal sml/mode-line-buffer-identification mode-line-buffer-identification)
-         (and (listp mode-line-buffer-identification)
-              (member (cadr sml/mode-line-buffer-identification) mode-line-buffer-identification))
-         (member sml/mode-line-buffer-identification mode-line-buffer-identification))
+  (when (and (listp mode-line-buffer-identification)
+             (or ;; Only calculate all this if it will actually be used
+              (equal sml/mode-line-buffer-identification mode-line-buffer-identification)
+              (member (cadr sml/mode-line-buffer-identification) mode-line-buffer-identification)
+              (member sml/mode-line-buffer-identification mode-line-buffer-identification)))
     (setq sml/buffer-identification
           (let* ((dir (sml/replacer (abbreviate-file-name (sml/get-directory))))
                  (sml/use-projectile-p (unless (or (not sml/projectile-loaded-p)
@@ -1542,7 +1542,7 @@ duplicated buffer names) from being displayed."
 (when sml/-hidden-modes-bound-by-user
   (setq sml/-hidden-modes-bound-by-user nil)
   (setq rm-blacklist (bound-and-true-p sml/hidden-modes)))
-(define-obsolete-variable-alias 'sml/hidden-modes 'rm-blacklist)
+(define-obsolete-variable-alias 'sml/hidden-modes 'rm-blacklist "2.9")
 
 (defun sml/generate-minor-modes ()
   "Extracts all rich strings necessary for the minor mode list."
